@@ -7,6 +7,9 @@ from ttkbootstrap import Style
 import tkinter
 from tkinter import ttk
 
+# for taking screenshots
+from PIL import ImageGrab
+
 
 class Demo(Style):
     """
@@ -19,11 +22,11 @@ class Demo(Style):
         self.root = self.master
         self.root.protocol("WM_DELETE_WINDOW", self.quit)
         self.root.title('TTK Bootstrap')
-        # self.root.geometry('590x650')
         self.theme_name = tkinter.StringVar()
         self.theme_name.set(self.theme_use())
         self.setup()
         self.root.eval('tk::PlaceWindow . center')
+        self.root.bind("<Insert>", self.get_bounding_box)
         self.run()
 
     def __repr__(self):
@@ -52,10 +55,6 @@ class Demo(Style):
         self.nb.select(self.nb.tabs()[0])
         self.theme_name.set(new_theme)
 
-    def checked(self, btn):
-        btn_text = "Unchecked" if btn['text'] == "Checked" else "Checked"
-        btn.configure(text=btn_text)
-
     def create_themed_tab(self):
         """
         Create a return a frame containing themed widgets
@@ -143,14 +142,14 @@ class Demo(Style):
         r2.pack(side='left', fill='x', expand='yes')
 
         # Checkbutton
-        cb1 = ttk.Checkbutton(options_frame, text='Unchecked')
-        cb1.configure(command=lambda: self.checked(cb1))
+        cb1 = ttk.Checkbutton(options_frame, text='Option 1')
         cb1.pack(side='left', fill='x', expand='yes')
         cb1.invoke()
 
-        cb2 = ttk.Checkbutton(options_frame, text='Unchecked')
-        cb2.configure(command=lambda: self.checked(cb2))
+        cb2 = ttk.Checkbutton(options_frame, text='Option 2')
         cb2.pack(side='left', fill='x', expand='yes')
+        cb2.invoke()
+        cb2.invoke()
 
         # Treeview
         tv = ttk.Treeview(widget_frame, height=3)
@@ -187,6 +186,28 @@ class Demo(Style):
         # I'm getting an error when closing the application without switching a standard theme ??
         self.root.destroy()
 
+    def get_bounding_box(self, event):
+        """
+        Take a screenshot of the current demo window and save to examples
+        """
+        # bounding box
+        titlebar = 31
+        x1 = self.root.winfo_rootx() - 1
+        y1 = self.root.winfo_rooty() - titlebar
+        x2 = x1 + self.root.winfo_width() + 2
+        y2 = y1 + self.root.winfo_height() + titlebar + 1
+
+        self.root.after_idle(self.save_screenshot, [x1, y1, x2, y2])
+
+    def save_screenshot(self, bbox):
+        # screenshot
+        img = ImageGrab.grab(bbox=bbox)
+
+        # image name
+        filename = f'../../examples/{self.theme_name.get()}.png'
+        img.save(filename, 'png')
+        print(filename)  # print for confirmation
+
 
 if __name__ == '__main__':
     Demo()
